ProSHADE: Class Hierarchy

| ProSHADE 0.7.5.1 (JAN 2021) Protein Shape Detection

Class Hierarchy
This inheritance list is sorted roughly, but not completely, alphabetically:
[detail level 12]

C ProSHADE_internal_maths::BicubicInterpolator |
C ProSHADE_internal_data::ProSHADE_data | This class contains all inputed and derived data for a single structure
C ProSHADE_internal_maths_bicubicInterpolator | This class takes 4 by 4 array of input point values and allows bicubic interpolation of any value between them
C ProSHADE_internal_spheres::ProSHADE_rotFun_sphere | This class contains all inputed data for the rotation function angle-axis converted spheres
C ProSHADE_internal_spheres::ProSHADE_rotFun_spherePeakGroup | This class contains peak groups detected in the rotation function mapped spheres
C ProSHADE_run | This class provides the access point to the library
C ProSHADE_settings | This class stores all the settings and is passed to the executive classes instead of a multitude of parameters
C ProSHADE_internal_spheres::ProSHADE_sphere | This class contains all inputed and derived data for a single sphere
▼Cruntime_error |
C ProSHADE_exception | This class is the representation of ProSHADE exception